<?php

namespace Drupal\taxonomy_proportion\Plugin\Field\FieldType;

use Drupal\Core\Field\Attribute\FieldType;
use Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;
use \Drupal\Core\Field\EntityReferenceFieldItemList;

/**
 * Plugin implementation of the 'taxonomy_proportion' field type.
 */
#[FieldType(
  id: "taxonomy_proportion",
  label: new TranslatableMarkup("Taxonomy proportion"),
  description: new TranslatableMarkup("Add a proportion to taxonomy terms."),
  default_widget: "taxonomy_proportion_autocomplete_widget",
  default_formatter: "taxonomy_proportion_formatter",
  list_class: EntityReferenceFieldItemList::class,
  category: "reference",
)]
class TaxonomyProportion extends EntityReferenceItem {

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    // Get the properties of the entity reference
    $properties = parent::propertyDefinitions($field_definition);

    // Add the proportion property
    $properties['proportion'] = DataDefinition::create('float')
      ->setLabel(t('Proportion'))
      ->setRequired(TRUE)
      ->setDescription(t('The proportion value associated with the taxonomy term.'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    // Get the schema of the entity reference
    $schema = parent::schema($field_definition);

    // Add the proportion column
    $schema['columns']['proportion'] = [
      'type' => 'float',
      'not null' => TRUE,
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function getPreconfiguredOptions() {
    return [];
  }
}